@@ -431,7 +431,7 @@ class ApplyResult(object):
                 traceback.print_exc()
 
     def _set_exception(self):
-        """Called by a Job object to tell that an exception occured
+        """Called by a Job object to tell that an exception occurred
 
         during the processing of the function. The object will become
         ready but not successful. The collector's notify_ready()
