@@ -592,7 +592,7 @@ def load_check_directory():
             continue
 
         # Look for the per-check config, which *must* exist
-        if not check_config.get('instances'):
+        if 'instances' not in check_config:
             log.error("Config %s is missing 'instances'" % conf_path)
             continue
 
@@ -725,3 +725,10 @@ def chunks(iterable, chunk_size):
             if count:
                 yield chunk[:count]
             break
+
+
+def get_sub_collection_warn():
+    config = configuration.Config()
+    agent_config = config.get_config(sections='Main')
+    sub_collection_warn = agent_config.get('sub_collection_warn')
+    return sub_collection_warn
